| Home | Libraries | People | FAQ | More

### conditional

Header: `#include <boost/type_traits/conditional.hpp>` or `#include <boost/type_traits.hpp>`

    namespace boost {
      template <bool B, class T, class U>  struct conditional;
      template <bool B, class T, class U>  using conditional_t = typename conditional<B, T, U>::type; // C++11 and above
    }

If B is true, the member typedef type shall equal T. If B is false, the member typedef type shall equal U.